@@ -15,8 +15,8 @@ use std::collections::HashMap;
 use std::ffi::{CStr, CString};
 use std::fmt::{self, Debug, Formatter};
 use std::marker::PhantomData;
-use std::sync::{Arc, Mutex, Weak};
 use std::sync::mpsc::Sender;
+use std::sync::{Arc, Mutex, Weak};
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -34,23 +34,23 @@ pub use crate::user::*;
 pub use crate::user_stats::*;
 pub use crate::utils::*;
 
-mod error;
-mod callback;
-mod server;
-mod utils;
 mod app;
+mod callback;
+mod error;
 mod friends;
 mod matchmaking;
 mod networking;
+pub mod networking_messages;
+pub mod networking_sockets;
+mod networking_sockets_callback;
+pub mod networking_types;
+pub mod networking_utils;
+mod remote_storage;
+mod server;
+mod ugc;
 mod user;
 mod user_stats;
-mod remote_storage;
-mod ugc;
-pub mod networking_messages;
-pub mod networking_types;
-pub mod networking_sockets;
-pub mod networking_utils;
-mod networking_sockets_callback;
+mod utils;
 
 pub type SResult<T> = Result<T, SteamError>;
 
@@ -95,8 +95,13 @@ struct Callbacks {
 }
 
 struct NetworkingSocketsData<Manager> {
-    sockets: HashMap<sys::HSteamListenSocket,
-        (Weak<networking_sockets::InnerSocket<Manager>>, Sender<networking_types::ListenSocketEvent<Manager>>)>,
+    sockets: HashMap<
+        sys::HSteamListenSocket,
+        (
+            Weak<networking_sockets::InnerSocket<Manager>>,
+            Sender<networking_types::ListenSocketEvent<Manager>>,
+        ),
+    >,
     /// Connections to a remote listening port
     independent_connections: HashMap<sys::HSteamNetConnection, Sender<()>>,
     connection_callback: Weak<CallbackHandle<Manager>>,
@@ -346,7 +351,7 @@ impl<Manager> Client<Manager> {
     /// Returns an accessor to the steam remote storage interface
     pub fn remote_storage(&self) -> RemoteStorage<Manager> {
         unsafe {
-            let rs = sys::SteamAPI_SteamRemoteStorage_v014();
+            let rs = sys::SteamAPI_SteamRemoteStorage_v016();
             debug_assert!(!rs.is_null());
             let util = sys::SteamAPI_SteamUtils_v010();
             debug_assert!(!util.is_null());
@@ -361,7 +366,7 @@ impl<Manager> Client<Manager> {
     /// Returns an accessor to the steam UGC interface (steam workshop)
     pub fn ugc(&self) -> UGC<Manager> {
         unsafe {
-            let ugc = sys::SteamAPI_SteamUGC_v015();
+            let ugc = sys::SteamAPI_SteamUGC_v016();
             debug_assert!(!ugc.is_null());
             UGC {
                 ugc,
@@ -383,7 +388,7 @@ impl<Manager> Client<Manager> {
 
     pub fn networking_sockets(&self) -> networking_sockets::NetworkingSockets<Manager> {
         unsafe {
-            let sockets = sys::SteamAPI_SteamNetworkingSockets_SteamAPI_v009();
+            let sockets = sys::SteamAPI_SteamNetworkingSockets_SteamAPI_v012();
             debug_assert!(!sockets.is_null());
             networking_sockets::NetworkingSockets {
                 sockets,
@@ -394,7 +399,7 @@ impl<Manager> Client<Manager> {
 
     pub fn networking_utils(&self) -> networking_utils::NetworkingUtils<Manager> {
         unsafe {
-            let utils = sys::SteamAPI_SteamNetworkingUtils_SteamAPI_v003();
+            let utils = sys::SteamAPI_SteamNetworkingUtils_SteamAPI_v004();
             debug_assert!(!utils.is_null());
             networking_utils::NetworkingUtils {
                 utils,
